PyXMake Developer Guide: PyXMake.VTL.stm_make.pyx_app Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | Static Public Attributes | Protected Member Functions | Static Protected Attributes | List of all members
PyXMake.VTL.stm_make.pyx_app Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.pyx_app:

## Public Member Functions
| initialize_options (self)
| finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| run (self)

## Public Attributes
int | verbose = 0
str | source_path = ''
str | output_file_path = ''
str | mode = "onedir"
| scratch_path = os.getcwd()
| include = None
| dependency = None
Public Attributes inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| verbose

## Static Public Attributes
str | description = "Compile a stand-alone application using PyInstaller."
list | user_options

## Protected Member Functions
| _run_command (self, command)
Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_command (self)
| _perform_post_actions (self)

## Static Protected Attributes
str | _APP_NAME = ''
str | _INPUT_SCRIPT = ""

## Additional Inherited Members
Static Protected Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
| _create_build_dir ()

## Detailed Description

    Base class for encapsulating command line arguments and build process.

Definition at line 100 of file stm_make.py.

## Member Function Documentation

## ◆ _run_command()

PyXMake.VTL.stm_make.pyx_app._run_command | ( |  | self,
|  |  | command )
| protected

    Execute build command

Reimplemented from PyXMake.VTL.stm_make._BaseCommandRunner.

Definition at line 138 of file stm_make.py.

## ◆ finalize_options()

PyXMake.VTL.stm_make.pyx_app.finalize_options | ( |  | self | ) |

    Post-process options.

Definition at line 130 of file stm_make.py.

## ◆ initialize_options()

PyXMake.VTL.stm_make.pyx_app.initialize_options | ( |  | self | ) |

    Set default values for options.

Definition at line 117 of file stm_make.py.

## Member Data Documentation

## ◆ _APP_NAME

PyXMake.VTL.stm_make.pyx_app._APP_NAME = ''
| staticprotected

Definition at line 104 of file stm_make.py.

## ◆ _INPUT_SCRIPT

str PyXMake.VTL.stm_make.pyx_app._INPUT_SCRIPT = ""
| staticprotected

Definition at line 105 of file stm_make.py.

## ◆ dependency

PyXMake.VTL.stm_make.pyx_app.dependency = None

Definition at line 128 of file stm_make.py.

## ◆ description

str PyXMake.VTL.stm_make.pyx_app.description = "Compile a stand-alone application using PyInstaller."
| static

Definition at line 107 of file stm_make.py.

## ◆ include

PyXMake.VTL.stm_make.pyx_app.include = None

Definition at line 127 of file stm_make.py.

## ◆ mode

str PyXMake.VTL.stm_make.pyx_app.mode = "onedir"

Definition at line 125 of file stm_make.py.

## ◆ output_file_path

str PyXMake.VTL.stm_make.pyx_app.output_file_path = ''

Definition at line 124 of file stm_make.py.

## ◆ scratch_path

PyXMake.VTL.stm_make.pyx_app.scratch_path = os.getcwd()

Definition at line 126 of file stm_make.py.

## ◆ source_path

PyXMake.VTL.stm_make.pyx_app.source_path = ''

Definition at line 123 of file stm_make.py.

## ◆ user_options

list PyXMake.VTL.stm_make.pyx_app.user_options
| static

Initial value:
= [
# The format is (long option, short option, description).
('source-path=', None, 'path to the folder holding source files'),
('verbose=', None, 'controls the logging level (0 - Nothing, 2- Everything) Default: 0 - Nothing'),
('mode=', None, 'define application build mode (one directory or one file mode)'),
('scratch-path=', None, 'path to scratch folder where all temporary data is located during the build event'),
('output-file-path=', None, 'path to the output directory'),
]

Definition at line 108 of file stm_make.py.

## ◆ verbose

int PyXMake.VTL.stm_make.pyx_app.verbose = 0

Definition at line 122 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py